==> xconvers-0.6.tar.gz: xconvers-0.6/src/callbacks.h <==
/*  
 *  xconvers - GTK+ client for amateur radio convers
 *  Copyright (C) 2000-2001 Joop Stakenborg <pa4tu@amsat.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 *  callback.h
 */

#include <gtk/gtk.h>

/* main window */

void on_mainwindow_destroy(GtkObject *object, gpointer user_data);
gboolean on_mainwindow_delete_event (GtkWidget *widget, GdkEvent *event,
  gpointer user_data);
gboolean on_mainwindow_key_press_event(GtkWidget *widget, GdkEventKey *event,
  gpointer user_data);
void on_mainentry_activate (GtkEditable *editable, gpointer user_data);
void on_mainwindow_show (GtkWidget *widget, gpointer user_data);

/* menus */

void on_exit_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_open_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_close_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_preferences_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_about_activate (GtkMenuItem *menuitem, gpointer user_data);

/* about dialog */

void on_aboutdialog_show (GtkWidget *widget, gpointer user_data);
void on_aboutOKbutton_clicked (GtkButton *button, gpointer user_data);

/* open dialog */

void on_opendialog_show (GtkWidget *widget, gpointer user_data);
void on_opendialog_destroy (GtkObject *object, gpointer user_data);
void on_openOKbutton_clicked (GtkButton *button, gpointer user_data);
void on_opencancelbutton_clicked (GtkButton *button, gpointer user_data);

/* close dialog */

void on_closedialog_destroy (GtkObject *object, gpointer user_data);
void on_closeOKbutton_clicked (GtkButton *button, gpointer user_data);
void on_closecancelbutton_clicked (GtkButton *button, gpointer user_data);

/* preferences dialog */

void on_preferencesdialog_show (GtkWidget *widget, gpointer user_data);
void on_preferencesdialog_destroy (GtkObject *object, gpointer user_data);
void on_preferencesOKbutton_clicked (GtkButton *button, gpointer user_data);
void on_preferencescancelbutton_clicked (GtkButton *button, 
  gpointer user_data);
void on_autologincheckbutton_toggled (GtkToggleButton *togglebutton,
  gpointer user_data);

void
on_backgroundcolorbutton_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_fontbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_colorselectiondialog_show           (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_colorok_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_colorcancel_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_fontselectiondialog_show            (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_fontok_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_fontcancel_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

==> xconvers_0.8.1.tar.gz: xconvers-0.8.1/src/callbacks.h <==
/*  
 *  xconvers - GTK+ client for amateur radio convers
 *  Copyright (C) 2000-2001 Joop Stakenborg <pa4tu@amsat.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 *  callback.h
 */

#include <gtk/gtk.h>

/* main window */

void on_mainwindow_destroy(GtkObject *object, gpointer user_data);
gboolean on_mainwindow_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data);
gboolean on_mainwindow_key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
void on_mainentry_activate (GtkEditable *editable, gpointer user_data);
void on_mainwindow_show (GtkWidget *widget, gpointer user_data);

/* menus */

void on_exit_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_open_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_close_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_preferences_activate (GtkMenuItem *menuitem, gpointer user_data);
void on_about_activate (GtkMenuItem *menuitem, gpointer user_data);

/* about dialog */

void on_aboutdialog_show (GtkWidget *widget, gpointer user_data);
void on_aboutOKbutton_clicked (GtkButton *button, gpointer user_data);

/* open dialog */

void on_opendialog_show (GtkWidget *widget, gpointer user_data);
void on_opendialog_destroy (GtkObject *object, gpointer user_data);
void on_openOKbutton_clicked (GtkButton *button, gpointer user_data);
void on_opencancelbutton_clicked (GtkButton *button, gpointer user_data);

/* close dialog */

void on_closedialog_destroy (GtkObject *object, gpointer user_data);
void on_closeOKbutton_clicked (GtkButton *button, gpointer user_data);
void on_closecancelbutton_clicked (GtkButton *button, gpointer user_data);

/* preferences dialog */

void on_preferencesdialog_show (GtkWidget *widget, gpointer user_data);
void on_preferencesdialog_destroy (GtkObject *object, gpointer user_data);
void on_preferencesOKbutton_clicked (GtkButton *button, gpointer user_data);
void on_preferencescancelbutton_clicked (GtkButton *button, gpointer user_data);
void on_autologincheckbutton_toggled (GtkToggleButton *togglebutton, gpointer user_data);
void on_fontbutton_clicked (GtkButton *button, gpointer user_data);
gboolean on_colorbutton_pressed_event (GtkWidget *widget, GdkEventButton *event, gpointer user_data);

/* color slection dialog */

void on_colorok_button_clicked (GtkButton *button, gpointer user_data);
void on_colorcancel_button_clicked (GtkButton *button, gpointer user_data);

/* font selection dialog */

void on_fontok_button_clicked (GtkButton *button, gpointer user_data);
void on_fontcancel_button_clicked (GtkButton *button, gpointer user_data);

void
on_fileok_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_filecancel_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_pixmapselectbutton_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_radiobutton_toggled                 (GtkToggleButton *togglebutton,
                                        gpointer         user_data);
